Learn R Programming

COST (version 0.1.0)

logL.COST.G: negtive log-likelihood for Gaussian copula

Description

gives the negtive log-likelihood of the Gaussian copula, with empirical CDF plugin, and it is for parameter estimation in the correlation matrix

Usage

logL.COST.G(par,Y,s.ob)

Arguments

par

parameters in the copula function, will be obtained by minimizing the negtive log-likelihood

Y

the data set from observed locations, used for parameter estimation

s.ob

coordinates of observed locations

Value

the negative log-likelihood

References

Yanlin Tang, Huixia Judy Wang, Ying Sun, Amanda Hering. Copula-based semiparametric models for spatio-temporal data.