gives the negtive log-likelihood of the t copula, with empirical CDF plugin, and it is for parameter estimation in the correlation matrix
logL.COST.t(par,Y,s.ob)parameters in the copula function, will be obtained by minimizing the negtive log-likelihood
the data set from observed locations, used for parameter estimation
coordinates of observed locations
the negative log-likelihood
Yanlin Tang, Huixia Judy Wang, Ying Sun, Amanda Hering. Copula-based semiparametric models for spatio-temporal data.